You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficserver.apache.org by jp...@apache.org on 2016/04/25 02:00:52 UTC

[trafficserver] branch master updated: Use traffic_ctl instead of traffic_line in TSQA.

This is an automated email from the ASF dual-hosted git repository.

jpeach pushed a commit to branch master
in repository https://git-dual.apache.org/repos/asf/trafficserver.git

The following commit(s) were added to refs/heads/master by this push:
       new  deb70bd   Use traffic_ctl instead of traffic_line in TSQA.
deb70bd is described below

commit deb70bd39a7292604629f4275369859f4c461df8
Author: James Peach <jp...@apache.org>
AuthorDate: Sun Apr 24 17:00:12 2016 -0700

    Use traffic_ctl instead of traffic_line in TSQA.
---
 ci/tsqa/tests/test_example.py                 | 11 ++++++-----
 ci/tsqa/tests/test_https.py                   |  3 ++-
 ci/tsqa/tests/test_tls_ticket_key_rotation.py |  7 +++++--
 3 files changed, 13 insertions(+), 8 deletions(-)

diff --git a/ci/tsqa/tests/test_https.py b/ci/tsqa/tests/test_https.py
index 4d0f57a..84cfba2 100644
--- a/ci/tsqa/tests/test_https.py
+++ b/ci/tsqa/tests/test_https.py
@@ -311,7 +311,8 @@ class TestConfigFileGroup(helpers.EnvironmentCase, CertSelectionMixin):
         log.info('cp %s %s' % (helpers.tests_file_path('rsa_keys/www.test.com.pem'), helpers.tests_file_path('www.unknown.com.pem')))
 
     def test_config_file_group(self):
-        signal_cmd = os.path.join(self.environment.layout.bindir, 'traffic_line') + ' -x'
+        traffic_ctl = os.path.join(self.environment.layout.bindir, 'traffic_ctl')
+        signal_cmd = [traffic_ctl, 'config', 'reload')]
         addr = ('127.0.0.3', self.ssl_port)
         cert = self._get_cert(addr, ciphers=CIPHER_MAP['rsa'])
         self.assertEqual(cert.get_subject().commonName.decode(), 'www.test.com')
diff --git a/ci/tsqa/tests/test_tls_ticket_key_rotation.py b/ci/tsqa/tests/test_tls_ticket_key_rotation.py
index 3fe98ce..45094ee 100644
--- a/ci/tsqa/tests/test_tls_ticket_key_rotation.py
+++ b/ci/tsqa/tests/test_tls_ticket_key_rotation.py
@@ -119,6 +119,7 @@ class TestTLSTicketKeyRotation(helpers.EnvironmentCase):
         '''
         Make sure the new ticket key is loaded
         '''
+        traffic_ctl = os.path.join(self.environment.layout.bindir, 'traffic_ctl')
         addr = ('127.0.0.1', self.ssl_port)
         self.start_connection(addr)
 
@@ -133,7 +134,9 @@ class TestTLSTicketKeyRotation(helpers.EnvironmentCase):
         # touch the ssl_multicert.config file
         ssl_multicert = os.path.join(self.environment.layout.sysconfdir, 'ssl_multicert.config')
 
-        read_renewed_cmd = os.path.join(self.environment.layout.bindir, 'traffic_line') + ' -r proxy.process.ssl.total_ticket_keys_renewed'
+        read_renewed_cmd = [
+            traffic_ctl, 'config', 'get', 'proxy.process.ssl.total_ticket_keys_renewed'
+        ]
 
         # Check whether the config file exists.
         self.assertTrue(os.path.isfile(ssl_multicert), ssl_multicert)
@@ -152,7 +155,7 @@ class TestTLSTicketKeyRotation(helpers.EnvironmentCase):
                 if count > 30:
                     self.assertTrue(False, "Failed to get the number of renewed keys!")
 
-        signal_cmd = os.path.join(self.environment.layout.bindir, 'traffic_line') + ' -x'
+        signal_cmd = [traffic_ctl, 'config', 'reload']
         tsqa.utils.run_sync_command(signal_cmd, stdout=subprocess.PIPE, shell=True)
 
         # wait for the ticket keys to be sucked in by traffic_server.

diff --git a/ci/tsqa/tests/test_example.py b/ci/tsqa/tests/test_example.py
index c59a96b..a0d04a1 100644
--- a/ci/tsqa/tests/test_example.py
+++ b/ci/tsqa/tests/test_example.py
@@ -64,7 +64,7 @@ class TestNoOp(helpers.EnvironmentCase):
         is an environment object)
         '''
         # we can modify any/all configs (note: all pre-daemon start)
-        cls.configs['remap.config'].add_line('map / http://http://trafficserver.readthedocs.org/')
+        cls.configs['remap.config'].add_line('map / http://trafficserver.readthedocs.org/')
 
         # Some configs have nicer wrapper objects to give you a more pythonic interface
         cls.configs['records.config']['CONFIG'].update({
@@ -101,13 +101,14 @@ class TestBootstrap(helpers.EnvironmentCase):
         self.assertEqual(ret.status_code, 404)
         self.assertIn('ATS', ret.headers['server'])
 
-    def test_trafficline(self):
+    def test_trafficctl(self):
         '''
         Test that traffic_line works, and verify that the values for proxy.config
         match what we put in records.config
         '''
-        cmd = [os.path.join(self.environment.layout.bindir, 'traffic_line'),
-               '-m',
+        cmd = [os.path.join(self.environment.layout.bindir, 'traffic_ctl'),
+               'config',
+               'match',
                'proxy.config',
                ]
         stdout, _ = tsqa.utils.run_sync_command(cmd, stdout=subprocess.PIPE)
@@ -101,13 +101,14 @@ class TestBootstrap(helpers.EnvironmentCase):
         '''
-        Test that traffic_line works, and verify that the values for proxy.config
+        Test that traffic_ctl works, and verify that the values for proxy.config
         match what we put in records.config
         '''
-- 
To stop receiving notification emails like this one, please contact
['"commits@trafficserver.apache.org" <co...@trafficserver.apache.org>'].